CombiningTerminalCapabilitiesDetector class
Combines results from multiple capability detectors.
This detector aggregates and reconciles capabilities reported by different detection strategies, resolving conflicts and producing a consolidated view of terminal capabilities.
- Inheritance
-
- Object
- TerminalCapabilitiesDetector
- CombiningTerminalCapabilitiesDetector
Constructors
-
CombiningTerminalCapabilitiesDetector({required Iterable<
TerminalCapabilitiesDetector> detectors}) -
Creates a new combining detector with the specified
detectors.
Properties
-
assumedCaps
→ Set<
Capability> -
Features that are likely supported but not confirmed
finalinherited
-
detectors
→ Iterable<
TerminalCapabilitiesDetector> -
The individual detectors to combine results from
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
supportedCaps
→ Set<
Capability> -
Features that are definitively supported by the terminal
finalinherited
-
unsupportedCaps
→ Set<
Capability> -
Features that are explicitly not supported
finalinherited
Methods
-
detect(
) → Future< void> -
Performs the capability detection process
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited