NativeTerminalImage class

Implementation of terminal images using native image processing.

This class provides functionality to display images in the terminal by converting them to colored terminal cells. It supports loading images from files and creating blank or filled image buffers.

Inheritance

Constructors

NativeTerminalImage.empty(Size size)
Creates an empty terminal image with the specified dimensions.
factory
NativeTerminalImage.filled(Size size, Color? color)
Creates a terminal image filled with a single color.
NativeTerminalImage.fromRealImage({required Image image, Color? backgroundColor})
Creates a terminal image from an existing image object.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size
The size of the image in terminal cells.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](Position position) Color?
Get the color at the specified position.
override
operator []=(Position position, Color? color) → void
Set the color at the specified position.
override

Static Methods

fromPath({required Size size, required String path, Color? backgroundColor}) NativeTerminalImage
Creates a terminal image from an image file.