NativeTerminalImage.filled constructor

NativeTerminalImage.filled(
  1. Size size,
  2. Color? color
)

Creates a terminal image filled with a single color.

size determines the dimensions of the image. color is the color to fill with, null for transparent.

Implementation

NativeTerminalImage.filled(Size size, Color? color)
  : _data = List.filled(size.width * size.height, color),
    _size = size;