PollingTerminalSizeTracker class

Windows-specific implementation of terminal size tracking.

Inheritance

Constructors

PollingTerminalSizeTracker({Duration interval = const Duration(milliseconds: 200)})
Creates a polling-based terminal size tracker.

Properties

currentSize Size
Current dimensions of the terminal window
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
listener ↔ void Function()?
Callback triggered when terminal size changes
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startTracking() → void
Begins monitoring terminal size changes
override
stopTracking() → void
Stops monitoring terminal size changes
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited