PosixTerminalSizeTracker class

POSIX-specific implementation of terminal size tracking.

Uses the SIGWINCH signal to detect terminal window resizes on Unix-like operating systems (Linux, macOS, etc).

Inheritance

Constructors

PosixTerminalSizeTracker()

Properties

currentSize Size
Current dimensions of the terminal window
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
listener ↔ void Function()?
Callback triggered when terminal size changes
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startTracking() → void
Begins monitoring terminal size changes
override
stopTracking() → void
Stops monitoring terminal size changes
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited