XtermTerminalCapabilitiesDetector class
Detects capabilities specific to XTerm-compatible terminals.
Uses environment variables and terminal type information to determine supported features in XTerm and compatible terminal emulators.
- Inheritance
-
- Object
- TerminalCapabilitiesDetector
- XtermTerminalCapabilitiesDetector
Constructors
Properties
-
assumedCaps
→ Set<
Capability> -
Features that are likely supported but not confirmed
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
supportedCaps
→ Set<
Capability> -
Features that are definitively supported by the terminal
finalinherited
-
unsupportedCaps
→ Set<
Capability> -
Features that are explicitly not supported
finalinherited
Methods
-
detect(
) → Future< void> -
Performs the capability detection process
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited