AllowedSignal enum

System signals that can be handled by the terminal application.

These signals correspond to standard POSIX signals that the application may need to respond to.

Inheritance
Available extensions

Values

sighup → const AllowedSignal

Hangup detected on controlling terminal

sigint → const AllowedSignal

Interrupt from keyboard (Ctrl+C)

sigterm → const AllowedSignal

Termination signal

sigusr1 → const AllowedSignal

User-defined signal 1

sigusr2 → const AllowedSignal

User-defined signal 2

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AllowedSignal>
A constant List of the values in this enum, in order of their declaration.