Capability enum
List of terminal capabilities.
These capabilities represent various features and options that may be supported by the terminal, such as color support and mouse event handling.
Values
- standardColors → const Capability
-
Support for
BasicTerminalColor - ansiColors → const Capability
- extendedColors → const Capability
-
Support for
XTermTerminalColor - trueColors → const Capability
-
Support for
RGBTerminalColor - alternateScreenBuffer → const Capability
-
If an alternate screen buffer is available or if for the viewport everything needs to be redrawn
- mouse → const Capability
-
Support for TerminalListener.mouseEvent
- bracketedPaste → const Capability
- uft8 → const Capability
- cursorBlinkingDisable → const Capability
-
Support for setting CursorState.blinking to false
- intenseTextDecoration → const Capability
-
Support for TextEffects.intense
- italicTextDecoration → const Capability
-
Support for TextEffects.italic
- underlineTextDecoration → const Capability
-
Support for TextEffects.underline
- doubleUnderlineTextDecoration → const Capability
-
Support for TextEffects.doubleUnderline
- crossedOutTextDecoration → const Capability
-
Support for TextEffects.crossedOut
- faintTextDecoration → const Capability
-
Support for TextEffects.faint
- textBlinkTextDecoration → const Capability
-
Support for at least TextEffects.slowBlink and possibly TextEffects.fastBlink
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
Capability> - A constant List of the values in this enum, in order of their declaration.