CursorState class final

Represents the state of the text cursor.

Includes the cursor's position and whether it is currently blinking.

Constructors

CursorState({required Position position, bool blinking = true})

Properties

blinking bool
final
hashCode int
The hash code for this object.
no setteroverride
position Position
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override