TerminalCanvas class abstract
The primary drawing surface for terminal user interfaces.
TerminalCanvas provides a set of high-level drawing operations that can be used to create complex terminal user interfaces. It handles text rendering, rectangles, borders, and image composition.
- Implementers
Constructors
Properties
Methods
-
drawBorderBox(
{required Rect rect, required BorderCharSet style, Color color, BorderDrawIdentifier drawId}) → void - Draws a box border around or within the specified rectangle.
-
drawBorderLine(
{required Position from, required Position to, required BorderCharSet style, Color color, BorderDrawIdentifier drawId}) → void - Draws a border line between two points.
-
drawColor(
{Color color}) → void -
Fills the complete background (and erases foreground)
with
coloror if none is provided erases everything. -
drawImage(
{required Position position, required covariant TerminalImage image}) → void - Composites a terminal image onto the canvas.
-
drawPoint(
{required Position position, Color? background, Foreground? foreground}) → void - Draws a single point on the canvas.
-
drawRect(
{required Rect rect, Color? background, Foreground? foreground}) → void - Draws a filled rectangle on the canvas.
-
drawText(
{required String text, required Position position, ForegroundStyle? style}) → void - Draws text on the canvas at the specified position.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited