drawBorderBox abstract method
void
drawBorderBox({
- required Rect rect,
- required BorderCharSet style,
- Color color,
- BorderDrawIdentifier drawId,
Draws a box border around or within the specified rectangle.
Uses style to determine the border characters and color
for the border color. The drawId helps manage border intersections.
Implementation
void drawBorderBox({
required Rect rect,
required BorderCharSet style,
Color color,
BorderDrawIdentifier drawId,
});