drawText abstract method
Draws text on the canvas at the specified position.
The text will be rendered starting at position, applying the optional
style for text formatting.
Implementation
void drawText({
required String text,
required Position position,
ForegroundStyle? style,
});