TerminalImage class abstract

A terminal image representation that can be drawn on the terminal canvas.

Terminal images are color-based buffers that can be created and manipulated before being rendered to the terminal screen.

Implementers

Constructors

TerminalImage()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size
The size of the image in terminal cells.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](Position position) Color?
Get the color at the specified position.
operator []=(Position position, Color? color) → void
Set the color at the specified position.