TerminalLogger class abstract

Constructors

TerminalLogger()

Properties

hashCode int
The hash code for this object.
no setterinherited
isActive bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
service TerminalService
no setter
width int
no setter

Methods

deleteLastLine(int count) → void
log(String text, {ForegroundStyle foregroundStyle, Color backgroundColor}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited