checkSupport abstract method
Checks if a specific capability is supported by the terminal.
Implementation
CapabilitySupport checkSupport(Capability capability);
Checks if a specific capability is supported by the terminal.
CapabilitySupport checkSupport(Capability capability);