drawBorderLine method

  1. @override
void drawBorderLine({
  1. required Position from,
  2. required Position to,
  3. required BorderCharSet style,
  4. Color color = const Color.normal(),
  5. BorderDrawIdentifier? drawId,
})
override

Draws a border line between two points.

The line is drawn from from to to using the specified style and color. The drawId helps manage line intersections.

Implementation

@override
void drawBorderLine({
  required Position from,
  required Position to,
  required BorderCharSet style,
  Color color = const Color.normal(),
  BorderDrawIdentifier? drawId,
}) {
  assert(
    from.x == to.x || from.y == to.y,
    "Points need to be either horizontally or vertically aligned.",
  );
  assert(from != to, "Points need to be different.");
}