doubleUnderline constant

TextEffects const doubleUnderline

Double underline decoration.

Mutually exclusive with underline.

Note: Some terminals may interpret this as disabling bold intensity rather than applying a double underline, therefore be sure to check the capabilities.

Implementation

static const doubleUnderline = TextEffects._decorationNumber(4);