ansi library
Classes
- AnsiTerminalService
- BorderCharSet
- A set of characters used to draw borders and lines in terminal UIs.
- Colors
- Utility class providing named constants for ANSI colors.
- CombiningTerminalCapabilitiesDetector
- Combines results from multiple capability detectors.
- CursorState
- Represents the state of the text cursor.
- DefaultTerminalListener
- MouseEvent
- Base class for mouse events in the terminal.
- MouseHoverEvent
- Represents mouse movement without button presses.
- MousePressEvent
- Represents a mouse button press or release event.
- MouseScrollEvent
- Represents mouse wheel scrolling.
- NativeTerminalImage
- Implementation of terminal images using native image processing.
- PollingTerminalSizeTracker
- Windows-specific implementation of terminal size tracking.
- PosixTerminalSizeTracker
- POSIX-specific implementation of terminal size tracking.
- TerminalCanvas
- The primary drawing surface for terminal user interfaces.
- TerminalCapabilitiesDetector
- Detects and tracks terminal capabilities.
- TerminalImage
- A terminal image representation that can be drawn on the terminal canvas.
- TerminalListener
- Interface for handling terminal events.
- TerminalLogger
- TerminalService
- Service for creating and managing terminal windows and associated objects.
- TerminalSizeTracker
- System for tracking and responding to terminal window size changes.
- TerminalViewport
- Abstract class for terminal windows.
- TerminfoTerminalCapabilitiesDetector
- Checks the terminfo database for capabilities
- TrueColorsTerminalCapabilitiesDetector
- checks the $COLORTERM environment variable for colorterm support
- WindowsTerminalCapabilitiesDetector
- Detects capabilities for Windows terminals
- XtermTerminalCapabilitiesDetector
- Detects capabilities specific to XTerm-compatible terminals.
Enums
- AllowedSignal
- System signals that can be handled by the terminal application.
- Capability
- List of terminal capabilities.
- CapabilitySupport
- Support levels for terminal capabilities.
- ControlCharacter
- Control characters and special keys that can be received as input.
- MouseButton
- Note: button 4-7 are used for scrolling
- MousePressEventType
Extension Types
- BorderDrawIdentifier
- Identifier used to track border drawing operations.
- Color
- Terminal color representation system supporting different color formats.
- Foreground
- A representation of a single character with a specific foreground color and text effects.
- ForegroundStyle
- A representation of a single character with a specific foreground color and text effects.
- Offset
- Represents a 2D vector offset with integer components.
- Position
- Represents an absolute position in the terminal with integer coordinates.
- Rect
- Represents a rectangular area in the terminal.
- Size
- Represents a two-dimensional size with integer width and height.
- TextEffects
- A set of text effects that can be applied to text in a terminal.
- TextStyle
- A style that can be applied to text in a terminal, consisting of a foreground color, an optional background color, and a set of text effects.