AnsiTerminalService class
- Inheritance
-
- Object
- TerminalService
- AnsiTerminalService
Constructors
- AnsiTerminalService({required TerminalCapabilitiesDetector capabilitiesDetector, required TerminalSizeTracker sizeTracker})
- Creates a new factory with specific capability detection and size tracking.
- AnsiTerminalService.agnostic({Duration? terminalSizePollingInterval})
-
Creates a factory with automatic configuration
corresponding to the current platform.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- listener ↔ TerminalListener?
-
getter/setter pairinherited
- logger ↔ _AnsiTerminalLogger
-
latefinaloverride-getter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- viewport ↔ _AnsiTerminalViewport
-
latefinaloverride-getter
Methods
-
attach(
) → Future< void> -
override
-
bell(
) → void -
Triggers the terminal bell (audible or visible alert).
override
-
checkSupport(
Capability capability) → CapabilitySupport -
Checks if a specific capability is supported by the terminal.
override
-
createImage(
{required Size size, String? filePath, Color? backgroundColor}) → NativeTerminalImage -
override
-
detach(
) → Future< void> -
override
-
loggerMode(
) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setTerminalTitle(
String title) → void -
Sets the terminal window title.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
trySetTerminalSize(
Size size) → void -
Tries to set the terminal size, adjusting if necessary.
override
-
viewPortMode(
) → void -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited