NativeTerminalImage.filled constructor
Creates a terminal image filled with a single color.
size determines the dimensions of the image.
color is the color to fill with, null for transparent.
Implementation
NativeTerminalImage.filled(Size size, Color? color)
: _data = List.filled(size.width * size.height, color),
_size = size;