BorderCharSet class
A set of characters used to draw borders and lines in terminal UIs.
Modified from: https://github.com/onepub-dev/dart_console which is forked from: https://github.com/timsneath/dart_console Copyright (c) 2025 onepub-dev SPDX-License-Identifier: BSD-3-Clause
Constructors
- BorderCharSet.ascii()
-
factory
- BorderCharSet.asciiFilled()
-
factory
- BorderCharSet.bold()
-
factory
- BorderCharSet.double()
-
factory
- BorderCharSet.none()
-
factory
- BorderCharSet.raw(String glyphs)
-
const
- BorderCharSet.rounded()
-
factory
- BorderCharSet.square()
-
factory
Properties
- bottomLeftCorner → int
-
no setter
- bottomRightCorner → int
-
no setter
- cross → int
-
no setter
- glyphs → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- horizontalLine → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- teeDown → int
-
no setter
- teeLeft → int
-
no setter
- teeRight → int
-
no setter
- teeUp → int
-
no setter
- topLeftCorner → int
-
no setter
- topRightCorner → int
-
no setter
- verticalLine → int
-
no setter
Methods
-
getCorrectGlyph(
bool left, bool top, bool right, bool bottom) → int -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited