CapabilitySupport enum
Support levels for terminal capabilities.
Used to indicate whether a specific capability is supported, unsupported, or somewhere in between.
- Inheritance
- Implemented types
- Available extensions
Values
- unsupported → const CapabilitySupport
-
if a capability is very likely to be unsupported
- unknown → const CapabilitySupport
-
if there is no information on if a capability is supported or not
- assumed → const CapabilitySupport
-
features that might work
- supported → const CapabilitySupport
-
features that will work with high degree of reliability
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
compareTo(
CapabilitySupport other) → int -
Compares this object to another object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CapabilitySupport> - A constant List of the values in this enum, in order of their declaration.