Utility class providing named constants for ANSI colors.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- aquamarine1 → const Color
- aquamarine1_alt1 → const Color
- aquamarine3 → const Color
- black → const Color
- The standard 16 ANSI colors.
- blue → const Color
- blue1 → const Color
- blue3 → const Color
- blue3_alt1 → const Color
- blueViolet → const Color
- brightBlack → const Color
- brightBlue → const Color
- brightCyan → const Color
- brightGreen → const Color
- brightMagenta → const Color
- brightRed → const Color
- brightWhite → const Color
- brightYellow → const Color
- cadetBlue → const Color
- cadetBlue_alt1 → const Color
- chartreuse1 → const Color
- chartreuse2 → const Color
- chartreuse2_alt1 → const Color
- chartreuse3 → const Color
- chartreuse3_alt1 → const Color
- chartreuse4 → const Color
- cornflowerBlue → const Color
- cornsilk1 → const Color
- cyan → const Color
- cyan1 → const Color
- cyan2 → const Color
- cyan3 → const Color
- darkBlue → const Color
- darkCyan → const Color
- darkGoldenrod → const Color
- darkGreen → const Color
- darkKhaki → const Color
- darkMagenta → const Color
- darkMagenta_alt1 → const Color
- darkOliveGreen1 → const Color
- darkOliveGreen1_alt1 → const Color
- darkOliveGreen2 → const Color
- darkOliveGreen3 → const Color
- darkOliveGreen3_alt1 → const Color
- darkOliveGreen3_alt2 → const Color
- darkOrange → const Color
- darkOrange3 → const Color
- darkOrange3_alt1 → const Color
- darkRed → const Color
- darkRed_alt1 → const Color
- darkSeaGreen → const Color
- darkSeaGreen1 → const Color
- darkSeaGreen1_alt1 → const Color
- darkSeaGreen2 → const Color
- darkSeaGreen2_alt1 → const Color
- darkSeaGreen3 → const Color
- darkSeaGreen3_alt1 → const Color
- darkSeaGreen4 → const Color
- darkSeaGreen4_alt1 → const Color
- darkSlateGray1 → const Color
- darkSlateGray2 → const Color
- darkSlateGray3 → const Color
- darkTurquoise → const Color
- darkViolet → const Color
- darkViolet_alt1 → const Color
- deepPink1 → const Color
- deepPink1_alt1 → const Color
- deepPink2 → const Color
- deepPink3 → const Color
- deepPink3_alt1 → const Color
- deepPink4 → const Color
- deepPink4_alt1 → const Color
- deepPink4_alt2 → const Color
- deepSkyBlue1 → const Color
- deepSkyBlue2 → const Color
- deepSkyBlue3 → const Color
- deepSkyBlue3_alt1 → const Color
- deepSkyBlue4 → const Color
- deepSkyBlue4_alt1 → const Color
- deepSkyBlue4_alt2 → const Color
- dodgerBlue1 → const Color
- dodgerBlue2 → const Color
- dodgerBlue3 → const Color
- gold1 → const Color
- gold3 → const Color
- gold3_alt1 → const Color
- green → const Color
- green1 → const Color
- green3 → const Color
- green3_alt1 → const Color
- green4 → const Color
- greenYellow → const Color
- grey0 → const Color
-
The extended 256 ANSI colors commonly known as xterm-256 colors
using the
Color.extendedconstructor. However missing the first 16 colors which are available above and useColor.ansi. - grey3 → const Color
- grey7 → const Color
- grey11 → const Color
- grey15 → const Color
- grey19 → const Color
- grey23 → const Color
- grey27 → const Color
- grey30 → const Color
- grey35 → const Color
- grey37 → const Color
- grey39 → const Color
- grey42 → const Color
- grey46 → const Color
- grey50 → const Color
- grey53 → const Color
- grey54 → const Color
- grey58 → const Color
- grey62 → const Color
- grey63 → const Color
- grey66 → const Color
- grey69 → const Color
- grey70 → const Color
- grey74 → const Color
- grey78 → const Color
- grey82 → const Color
- grey84 → const Color
- grey85 → const Color
- grey89 → const Color
- grey93 → const Color
- grey100 → const Color
- honeydew2 → const Color
- hotPink → const Color
- hotPink2 → const Color
- hotPink3 → const Color
- hotPink3_alt1 → const Color
- hotPink_alt1 → const Color
- indianRed → const Color
- indianRed1 → const Color
- indianRed1_alt1 → const Color
- indianRed_alt1 → const Color
- khaki1 → const Color
- khaki3 → const Color
- lightCoral → const Color
- lightCyan1 → const Color
- lightCyan3 → const Color
- lightGoldenrod1 → const Color
- lightGoldenrod2 → const Color
- lightGoldenrod2_alt1 → const Color
- lightGoldenrod2_alt2 → const Color
- lightGoldenrod3 → const Color
- lightGreen → const Color
- lightGreen_alt1 → const Color
- lightPink1 → const Color
- lightPink3 → const Color
- lightPink4 → const Color
- lightSalmon1 → const Color
- lightSalmon3 → const Color
- lightSalmon3_alt1 → const Color
- lightSeaGreen → const Color
- lightSkyBlue1 → const Color
- lightSkyBlue3 → const Color
- lightSkyBlue3_alt1 → const Color
- lightSlateBlue → const Color
- lightSlateGrey → const Color
- lightSteelBlue → const Color
- lightSteelBlue1 → const Color
- lightSteelBlue3 → const Color
- lightYellow3 → const Color
- magenta → const Color
- magenta1 → const Color
- magenta2 → const Color
- magenta2_alt1 → const Color
- magenta3 → const Color
- magenta3_alt1 → const Color
- magenta3_alt2 → const Color
- mediumOrchid → const Color
- mediumOrchid1 → const Color
- mediumOrchid1_alt1 → const Color
- mediumOrchid3 → const Color
- mediumPurple → const Color
- mediumPurple1 → const Color
- mediumPurple2 → const Color
- mediumPurple2_alt1 → const Color
- mediumPurple3 → const Color
- mediumPurple3_alt1 → const Color
- mediumPurple4 → const Color
- mediumSpringGreen → const Color
- mediumTurquoise → const Color
- mediumVioletRed → const Color
- mistyRose1 → const Color
- mistyRose3 → const Color
- orange1 → const Color
- orange3 → const Color
- orange4 → const Color
- orange4_alt1 → const Color
- orangeRed1 → const Color
- orchid → const Color
- orchid1 → const Color
- orchid2 → const Color
- paleGreen1 → const Color
- paleGreen1_alt1 → const Color
- paleGreen3 → const Color
- paleGreen3_alt1 → const Color
- paleTurquoise1 → const Color
- paleTurquoise4 → const Color
- paleVioletRed1 → const Color
- pink1 → const Color
- pink3 → const Color
- plum1 → const Color
- plum2 → const Color
- plum3 → const Color
- plum4 → const Color
- purple → const Color
- purple3 → const Color
- purple4 → const Color
- purple4_alt1 → const Color
- purple_alt1 → const Color
- red → const Color
- red1 → const Color
- red3 → const Color
- red3_alt1 → const Color
- rosyBrown → const Color
- royalBlue1 → const Color
- salmon1 → const Color
- sandyBrown → const Color
- seaGreen1 → const Color
- seaGreen1_alt1 → const Color
- seaGreen2 → const Color
- seaGreen3 → const Color
- skyBlue1 → const Color
- skyBlue2 → const Color
- skyBlue3 → const Color
- slateBlue1 → const Color
- slateBlue3 → const Color
- slateBlue3_alt1 → const Color
- springGreen1 → const Color
- springGreen2 → const Color
- springGreen2_alt1 → const Color
- springGreen3 → const Color
- springGreen3_alt1 → const Color
- springGreen4 → const Color
- steelBlue → const Color
- steelBlue1 → const Color
- steelBlue1_alt1 → const Color
- steelBlue3 → const Color
- tan → const Color
- thistle1 → const Color
- thistle3 → const Color
- turquoise2 → const Color
- turquoise4 → const Color
- violet → const Color
- wheat1 → const Color
- wheat4 → const Color
- white → const Color
- yellow → const Color
- yellow1 → const Color
- yellow2 → const Color
- yellow3 → const Color
- yellow3_alt1 → const Color
- yellow4 → const Color
- yellow4_alt1 → const Color