MouseEvent class sealed
Base class for mouse events in the terminal.
Provides common properties for all mouse-related events including modifier key states and cursor position.
- Implementers
Properties
- ctrlKeyPressed → bool
-
Whether the control key was pressed
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- metaKeyPressed → bool
-
Whether the meta (command/windows) key was pressed
final
- position → Position
-
The position of the mouse cursor when the event occurred
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shiftKeyPressed → bool
-
Whether the shift key was pressed during the event
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited