MousePressEvent class final
Represents a mouse button press or release event.
Includes information about which button was involved and the type of press.
- Inheritance
-
- Object
- MouseEvent
- MousePressEvent
Constructors
- MousePressEvent(bool shiftKeyPressed, bool metaKeyPressed, bool ctrlKeyPressed, Position position, MouseButton button, MousePressEventType pressType)
-
const
Properties
-
The mouse button that triggered the event
final
- ctrlKeyPressed → bool
-
Whether the control key was pressed
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- metaKeyPressed → bool
-
Whether the meta (command/windows) key was pressed
finalinherited
- position → Position
-
The position of the mouse cursor when the event occurred
finalinherited
- pressType → MousePressEventType
-
The type of press event (click, double-click, etc)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shiftKeyPressed → bool
-
Whether the shift key was pressed during the event
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited