MouseScrollEvent class final
Represents mouse wheel scrolling.
Contains information about the scroll amount in both x and y directions.
- Inheritance
-
- Object
- MouseEvent
- MouseScrollEvent
Constructors
Properties
- ctrlKeyPressed → bool
-
Whether the control key was pressed
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- metaKeyPressed → bool
-
Whether the meta (command/windows) key was pressed
finalinherited
- position → Position
-
The position of the mouse cursor when the event occurred
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shiftKeyPressed → bool
-
Whether the shift key was pressed during the event
finalinherited
- xScroll → int
-
The amount of scrolling in the x direction
final
- yScroll → int
-
The amount of scrolling in the y direction
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited