drawBorderBox abstract method

void drawBorderBox({
  1. required Rect rect,
  2. required BorderCharSet style,
  3. Color color,
  4. BorderDrawIdentifier drawId,
})

Draws a box border around or within the specified rectangle.

Uses style to determine the border characters and color for the border color. The drawId helps manage border intersections.

Implementation

void drawBorderBox({
  required Rect rect,
  required BorderCharSet style,
  Color color,
  BorderDrawIdentifier drawId,
});