drawText abstract method

void drawText({
  1. required String text,
  2. required Position position,
  3. ForegroundStyle? style,
})

Draws text on the canvas at the specified position.

The text will be rendered starting at position, applying the optional style for text formatting.

Implementation

void drawText({
  required String text,
  required Position position,
  ForegroundStyle? style,
});