TerminalImage class abstract
A terminal image representation that can be drawn on the terminal canvas.
Terminal images are color-based buffers that can be created and manipulated before being rendered to the terminal screen.
- Implementers
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
Position position) → Color? - Get the color at the specified position.
-
operator []=(
Position position, Color? color) → void - Set the color at the specified position.