drawBorderBox method
void
drawBorderBox({
- required Rect rect,
- required BorderCharSet style,
- Color color = const Color.normal(),
- BorderDrawIdentifier? drawId,
override
Draws a box border around or within the specified rectangle.
Uses style to determine the border characters and color
for the border color. The drawId helps manage border intersections.
Implementation
@override
void drawBorderBox({
required Rect rect,
required BorderCharSet style,
Color color = const Color.normal(),
BorderDrawIdentifier? drawId,
}) {
assert(rect.height > 1 && rect.width > 1, "Rect needs to be at least 2x2.");
}